@@ -302,8 +302,18 @@ impl AssociationInternal {
 
     /// handle_inbound parses incoming raw packets
     pub(crate) async fn handle_inbound(&mut self, raw: &Bytes) -> Result<()> {
-        let p = Packet::unmarshal(raw)?;
-        p.check_packet()?;
+        let p = match Packet::unmarshal(raw) {
+            Ok(p) => p,
+            Err(err) => {
+                log::warn!("[{}] unable to parse SCTP packet {}", self.name, err);
+                return Ok(());
+            }
+        };
+
+        if let Err(err) = p.check_packet() {
+            log::warn!("[{}] failed validating packet {}", self.name, err);
+            return Ok(());
+        }
 
         self.handle_chunk_start();
 
@@ -920,7 +930,7 @@ impl AssociationInternal {
         );
         self.stats.inc_datas();
 
-        let can_push = self.payload_queue.can_push(&d, self.peer_last_tsn);
+        let can_push = self.payload_queue.can_push(d, self.peer_last_tsn);
         let mut stream_handle_data = false;
         if can_push {
             if let Some(_s) = self.get_or_create_stream(d.stream_identifier) {
@@ -1409,7 +1419,7 @@ impl AssociationInternal {
         }
 
         // Process selective ack
-        let (bytes_acked_per_stream, htna) = self.process_selective_ack(&d).await?;
+        let (bytes_acked_per_stream, htna) = self.process_selective_ack(d).await?;
 
         let mut total_bytes_acked = 0;
         for n_bytes_acked in bytes_acked_per_stream.values() {
